@@ -1,4 +1,4 @@
-if (Sys.getenv("_R_CHECK_FULL_") != "") {
+if (Sys.getenv("_R_CHECK_FULL_") != "" && Sys.getenv("_R_CHECK_USE_VALGRIND_") == "") {
 
 if (require("R.rsp")) {
   html <- matrixStats:::benchmark('binCounts')
